@@ -6,25 +6,156 @@ use base qw( Sys::Info::Base );
 use Carp qw( croak );
 use Sys::Info::Driver::Linux;
 use Sys::Info::Constants qw( :linux );
-use Sys::Info::Driver::Linux::OS::Distribution::Conf;
 
-our $VERSION = '0.75_01';
+our $VERSION = '0.73';
 
-#<REMOVE>
-my $RELX = sub {
-    my $master = shift;
-    my $t = sub {
-        my($k, $v) = @_;
-	return map { $_ => $v} ref $k ? @{$k} : ($k);
-    };
-    map  { $t->($CONF{$_}->{$master}, $_ ) }
-    grep {      $CONF{$_}->{$master}       }
-    keys %CONF
+my %ORIGINAL_RELEASE = qw(
+    arch-release            arch
+    debian_version          debian
+    debian_release          debian
+    gentoo-release          gentoo
+    mandrake-release        mandrake
+    mandrakelinux-release   mandrakelinux
+    redhat-release          redhat
+    redhat_version          redhat
+    slackware-version       slackware
+    slackware-release       slackware
+    SuSE-release            suse
+);
+
+my %DERIVED_RELEASE = qw(
+    adamantix_version       adamantix
+    conectiva-release       conectiva
+    fedora-release          fedora
+    immunix-release         immunix
+    knoppix-version         knoppix
+    libranet_version        libranet
+    pardus-release          pardus
+    redflag-release         redflag
+    tinysofa-release        tinysofa
+    trustix-release         trustix
+    turbolinux-release      turbolinux
+    va-release              va-linux
+    yellowdog-release       yellowdog
+    yoper-release           yoper
+);
+
+my %version_match = (
+    'gentoo'    => 'Gentoo Base System version (.*)',
+    'debian'    => '(.+)',
+    'suse'      => 'VERSION = (.*)',
+    'fedora'    => 'Fedora Core release (\d+) \(',
+    'redflag'   => 'Red Flag (?:Desktop|Linux) (?:release |\()(.*?)(?: \(.+)?\)',
+    'redhat'    => 'Red Hat Linux release (.*) \(',
+    'slackware' => '^Slackware (.+)$',
+    'pardus'    => '^Pardus (.+)$',
+);
+
+my %DISTROFIX = qw( suse SUSE );
+
+my $EDITION   = {
+    # taken from wikipedia
+    ubuntu => {
+         '4.10' => 'Warty Warthog',
+         '5.04' => 'Hoary Hedgehog',
+         '5.10' => 'Breezy Badger',
+         '6.06' => 'Dapper Drake',
+         '6.10' => 'Edgy Eft',
+         '7.04' => 'Feisty Fawn',
+         '7.10' => 'Gutsy Gibbon',
+         '8.04' => 'Hardy Heron',
+         '8.10' => 'Intrepid Ibex',
+         '9.04' => 'Jaunty Jackalope',
+         '9.10' => 'Karmic Koala',
+	'10.04' => 'Lucid Lynx',
+    },
+    debian => {
+        '1.1' => 'buzz',
+        '1.2' => 'rex',
+        '1.3' => 'bo',
+        '2.0' => 'hamm',
+        '2.1' => 'slink',
+        '2.2' => 'potato',
+        '3.0' => 'woody',
+        '3.1' => 'sarge',
+        '4.0' => 'etch',
+        '5.0' => 'lenny',
+        '6.0' => 'squeeze',
+    },
+    fedora => {
+         '1' => 'Yarrow',
+         '2' => 'Tettnang',
+         '3' => 'Heidelberg',
+         '4' => 'Stentz',
+         '5' => 'Bordeaux',
+         '6' => 'Zod',
+         '7' => 'Moonshine',
+         '8' => 'Werewolf',
+         '9' => 'Sulphur',
+        '10' => 'Cambridge',
+        '11' => 'Leonidas',
+        '12' => 'Constantine',
+        '13' => 'Goddard',
+    },
+    mandriva => {
+           '5.1' => 'Venice',
+           '5.2' => 'Leeloo',
+           '5.3' => 'Festen',
+           '6.0' => 'Venus',
+           '6.1' => 'Helios',
+           '7.0' => 'Air',
+           '7.1' => 'Helium',
+           '7.2' => 'Odyssey',
+           '8.0' => 'Traktopel',
+           '8.1' => 'Vitamin',
+           '8.2' => 'Bluebird',
+           '9.0' => 'Dolphin',
+           '9.1' => 'Bamboo',
+           '9.2' => 'FiveStar',
+          '10.0' => 'Community',
+          '10.1' => 'Community',
+          '10.1' => 'Official',
+          '10.2' => 'Limited Edition 2005',
+        '2006.0' => '2006',
+        '2007'   => '2007',
+        '2007.1' => '2007 Spring',
+        '2008.0' => '2008',
+        '2008.1' => '2008 Spring',
+        '2009.0' => '2009',
+        '2009.1' => '2009 Spring',
+        '2010.0' => '2010',
+    },
 };
 
-my %ORIGINAL_RELEASE = $RELX->('release');
-my %DERIVED_RELEASE  = $RELX->('release_derived');
-#</REMOVE>
+my $MANUFACTURER = {
+    # taken from wikipedia
+    ubuntu    => 'Canonical Ltd. / Ubuntu Foundation',
+    centos    => 'Lance Davis',
+    fedora    => 'Fedora Project',
+    debian    => 'Debian Project',
+    mandriva  => 'Mandriva',
+    knoppix   => 'Klaus Knopper',
+    gentoo    => 'Gentoo Foundation',
+    suse      => 'Novell',
+    slackware => 'Patrick Volkerding',
+};
+
+my %DEBIAN_VFIX = (
+    # we get the version as "lenny/sid" for example
+    buzz   => '1.1',
+    rex    => '1.2',
+    bo     => '1.3',
+    hamm   => '2.0',
+    slink  => '2.1',
+    potato => '2.2',
+    woody  => '3.0',
+    sarge  => '3.1',
+    etch   => '4.0',
+    lenny  => '5.0',
+);
+
+my $EDITION_SUPPORT      = join q{|}, keys %{ $EDITION      };
+my $MANUFACTURER_SUPPORT = join q{|}, keys %{ $MANUFACTURER };
 
 sub new {
     my $class = shift;
@@ -34,7 +165,7 @@ sub new {
         'DISTRIB_CODENAME'    => q{},
         'DISTRIB_DESCRIPTION' => q{},
         'release_file'        => q{},
-        pattern               => q{},
+        'pattern'             => q{},
 	PROBE   => undef,
 	RESULTS => undef,
     };
@@ -43,18 +174,17 @@ sub new {
     return $self;
 }
 
-sub raw_name     { return shift->{RESULTS}{raw_name} }
-sub name         { return shift->{RESULTS}{name}     }
-sub version      { return shift->{RESULTS}{version}  }
-sub edition      { return shift->{RESULTS}{edition}  }
-sub kernel       { return shift->{PROBE}{kernel}     }
-sub build        { return shift->{PROBE}{build}      }
-sub build_date   { return shift->{PROBE}{build_date} }
+sub name       { return shift->{RESULTS}{name}    }
+sub version    { return shift->{RESULTS}{version} }
+sub edition    { return shift->{RESULTS}{edition} }
+sub kernel     { return shift->{PROBE}{kernel}            }
+sub build      { return shift->{PROBE}{build}             }
+sub build_date { return shift->{PROBE}{build_date}        }
 sub manufacturer {
     my $self = shift;
-    my $slot = $CONF{ lc $self->raw_name } || return;
-    return if ! exists $slot->{manufacturer};
-    return $slot->{manufacturer};
+    return $self->name =~ m{ ($MANUFACTURER_SUPPORT) }xmsi
+            ? $MANUFACTURER->{ lc $1 }
+	    : undef;
 }
 
 sub _probe {
@@ -62,7 +192,6 @@ sub _probe {
     return $self->{RESULTS} if $self->{RESULTS};
     $self->{RESULTS} = {};
     $self->{RESULTS}->{name}    = $self->_probe_name;
-    $self->{RESULTS}->{raw_name} = $self->{RESULTS}->{name};
     $self->{RESULTS}->{version} = $self->_probe_version;
     # this has to be last, since this also modifies the two above
     $self->{RESULTS}->{edition} = $self->_probe_edition;
@@ -80,9 +209,7 @@ sub _probe_name {
 sub _probe_release {
     my($self, $r) = @_;
     foreach my $id ( keys %{ $r } ) {
-	# we can't use "-l _" here. it'll die on some systems
-	# XXX: check if -l check is really necessary
-        if ( -f "/etc/$id" && !-l "/etc/$id" ){
+        if ( -f "/etc/$id" && !-l _ ){
             $self->{'DISTRIB_ID'}   = $r->{$id};
             $self->{'release_file'} = $id;
             return $self->{'DISTRIB_ID'};
@@ -98,8 +225,7 @@ sub _probe_version {
     if (! $self->{'DISTRIB_ID'}){
          $self->name() or croak 'No version because no distribution';
     }
-    my $slot = $CONF{ lc $self->{'DISTRIB_ID'} };
-    $self->{pattern} = exists $slot->{version_match} ? $slot->{version_match} : q{};
+    $self->{'pattern'} = $version_match{$self->{'DISTRIB_ID'}};
     $release = $self->_get_file_info();
     $self->{'DISTRIB_RELEASE'} = $release;
     return $release;
@@ -110,8 +236,7 @@ sub _probe_edition {
     my $p    = $self->{PROBE};
 
     if ( my $dn = $self->name ) {
-	my $slot = $CONF{ $dn };
-        $dn  = exists $slot->{name} ? $slot->{name} : ucfirst $dn;
+        $dn  = $DISTROFIX{$dn} || ucfirst $dn;
         $dn .= ' Linux';
 	$self->{RESULTS}{name}    = $dn;
     }
@@ -120,16 +245,19 @@ sub _probe_edition {
 	$self->{RESULTS}{version} = $p->{kernel};
     }
 
-    my $name     = $self->name;
-    my $raw_name = $self->raw_name;
-    my $version  = $self->version;
-    my $slot     = $CONF{$raw_name} || return;
-    my $edition  = exists $slot->{edition} ? $slot->{edition}{ $version } : undef;
+    my $name = $self->name;
+    my $version = $self->version;
+
+    my $edition;
+    if ( $name =~ m{ ($EDITION_SUPPORT) }xmsi ) {
+        my $id = lc $1;
+        $edition = $EDITION->{ $id }{ $version };
+    }
 
     if ( ! $edition && $version && $version !~ m{[0-9]}xms ) {
-        if ( $name =~ /debian/xmsi ) {
+        if ( $name =~ /Debian/xmsi ) {
             my @buf = split m{/}xms, $version;
-            if ( my $test = $CONF{debian}->{vfix}{ lc $buf[0] } ) {
+            if ( my $test = $DEBIAN_VFIX{ lc $buf[0] } ) {
                 # Debian version comes as the edition name
                 $edition = $version;
                 $self->{RESULTS}{version} = $test;
@@ -194,7 +322,7 @@ sub _get_lsb_info {
 
     if ( -r '/etc/' . STD_RELEASE ) {
         $self->{'release_file'} = STD_RELEASE;
-        $self->{pattern} = $field . '=(.+)';
+        $self->{'pattern'} = $field . '=(.+)';
         my $info = $self->_get_file_info();
         if ($info){
             $self->{$field} = $info;
@@ -211,18 +339,16 @@ sub _get_file_info {
     my $self = shift;
     my $file = '/etc/' . $self->{'release_file'};
     open my $FH, '<', $file or croak "Cannot open file: $file";
-    my @raw = <$FH>;
-    close $FH or croak "Can't close FH($file): $!";
     my $rv;
-    foreach my $line ( @raw ){
-        chomp $line;
-	## no critic (RequireExtendedFormatting)
-        my($info) = $line =~ m/$self->{pattern}/ms;
+    while (<$FH>){
+        chomp $_;
+        my($info) = $_ =~ m/$self->{pattern}/;
         if ( $info ) {
 	    $rv = "\L$info";
 	    last;
 	}
     }
+    close $FH or croak "Can't close FH($file): $!";
     return $rv;
 }
 
@@ -250,12 +376,8 @@ Sys::Info::Driver::Linux::OS::Distribution - Linux distribution probe
 
 =head1 DESCRIPTION
 
-This document describes version C<0.75_01> of C<Sys::Info::Driver::Linux::OS::Distribution>
-released on C<10 April 2010>.
-
-B<WARNING>: This version of the module is part of a
-developer (beta) release of the distribution and it is
-not suitable for production use.
+This document describes version C<0.73> of C<Sys::Info::Driver::Linux::OS::Distribution>
+released on C<14 January 2010>.
 
 This is a simple module that tries to guess on what linux distribution
 we are running by looking for release's files in /etc.  It now looks for
@@ -286,8 +408,6 @@ encouraged to submit patches.
 
 =head2 new
 
-=head2 raw_name
-
 =head2 version
 
 =head1 TODO
